'use strict';

var path = require('path');
var Arborist = require('@npmcli/arborist');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Arborist__default = /*#__PURE__*/_interopDefaultLegacy(Arborist);

const levels = [
    'silly',
    'verbose',
    'info',
    'timing',
    'http',
    'notice',
    'warn',
    'error',
    'silent',
];
function processLogger() {
    const logger = {};
    for (const level of levels) {
        logger[level] = (prefix, message, ...args) => {
            process.emit('log', level, prefix, message, ...args);
        };
    }
    for (const method of ['pause', 'resume']) {
        logger[method] = () => {
            process.emit('log', method);
        };
    }
    return logger;
}

async function run({ logger = processLogger(), ...options }) {
    logger.resume();
    logger.info('run', 'Count those tree rings!');
    const cwd = options.cwd ? path.resolve(options.cwd) : process.cwd();
    logger.silly('run', 'cwd = %j', cwd);
    const arb = new Arborist__default['default']({
        path: cwd,
    });
    const tree = await arb.loadVirtual().catch(() => arb.loadActual());
    logger.verbose('workspaces', '%O', tree.workspaces);
    return tree;
    /* c8 ignore next */
}

exports.levels = levels;
exports.run = run;
