'use strict';

var yargs = require('yargs/yargs');
var helpers = require('yargs/helpers');
var npmlog = require('npmlog');
var api = require('./api-c635c4de.js');
require('path');
require('@npmcli/arborist');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var yargs__default = /*#__PURE__*/_interopDefaultLegacy(yargs);
var npmlog__default = /*#__PURE__*/_interopDefaultLegacy(npmlog);

function configure(slicedArgv) {
    return yargs__default['default'](slicedArgv)
        .scriptName('dendrochronologist')
        .usage('$0', 'Version and publish npm packages in a monorepo.')
        .option('cwd', {
        type: 'string',
        describe: 'Current working directory',
        defaultDescription: 'process.cwd()',
        global: true,
        hidden: true,
    })
        .option('quiet', {
        type: 'boolean',
        describe: 'Only log errors and warnings',
        global: true,
    })
        .option('verbose', {
        type: 'boolean',
        describe: 'Log many details otherwise obscured',
        global: true,
    })
        .option('loglevel', {
        choices: api.levels.slice().reverse(),
        describe: 'Choose the level of logs explicitly',
        defaultDescription: '"info"',
        global: true,
    })
        .check((argv) => {
        if (argv.quiet) {
            argv.loglevel = 'warn';
        }
        if (argv.verbose) {
            argv.loglevel = 'verbose';
        }
        return true;
    }, true)
        .alias('h', 'help')
        .alias('v', 'version');
}
function execute(rawArgv) {
    const cli = configure(helpers.hideBin(rawArgv));
    // TODO: maybe spread out when hidden options are shown?
    cli.wrap(/* cli.terminalWidth() */ 80);
    const argv = cli.parse();
    npmlog__default['default'].heading = argv.$0;
    npmlog__default['default'].level = argv.loglevel || 'info';
    npmlog__default['default'].pause();
    npmlog__default['default'].verbose('argv', '%O', argv);
    api.run({
        ...argv,
        logger: npmlog__default['default'],
    });
}

exports.execute = execute;
