import yargs from 'yargs/yargs';
import { hideBin } from 'yargs/helpers';
import npmlog from 'npmlog';
import { levels, run } from './api-382488d7.mjs';
import 'path';
import '@npmcli/arborist';

function configure(slicedArgv) {
    return yargs(slicedArgv)
        .scriptName('dendrochronologist')
        .usage('$0', 'Version and publish npm packages in a monorepo.')
        .option('cwd', {
        type: 'string',
        describe: 'Current working directory',
        defaultDescription: 'process.cwd()',
        global: true,
        hidden: true,
    })
        .option('quiet', {
        type: 'boolean',
        describe: 'Only log errors and warnings',
        global: true,
    })
        .option('verbose', {
        type: 'boolean',
        describe: 'Log many details otherwise obscured',
        global: true,
    })
        .option('loglevel', {
        choices: levels.slice().reverse(),
        describe: 'Choose the level of logs explicitly',
        defaultDescription: '"info"',
        global: true,
    })
        .check((argv) => {
        if (argv.quiet) {
            argv.loglevel = 'warn';
        }
        if (argv.verbose) {
            argv.loglevel = 'verbose';
        }
        return true;
    }, true)
        .alias('h', 'help')
        .alias('v', 'version');
}
function execute(rawArgv) {
    const cli = configure(hideBin(rawArgv));
    // TODO: maybe spread out when hidden options are shown?
    cli.wrap(/* cli.terminalWidth() */ 80);
    const argv = cli.parse();
    npmlog.heading = argv.$0;
    npmlog.level = argv.loglevel || 'info';
    npmlog.pause();
    npmlog.verbose('argv', '%O', argv);
    run({
        ...argv,
        logger: npmlog,
    });
}

export { execute };
